// fl_picsee  -- A FLTK-based picture viewer 
#define appver "0.8.2"	// Last update 2009-04-14

/* -------------------------------------------------------
   Copyright 2009 Michael A. Losh
   
    "FLTK Picture-See" (also known as "fl_picsee")  is free software: 
	you can redistribute it and/or modify it under the terms of 
    the GNU General Public License as published by the
    Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    FLTK Picture-See is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with FLTK Picture-See.  If not, see <http://www.gnu.org/licenses/>.
-----------------------------------------------------------------*/

#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <FL/Fl.H>
#include <FL/Fl_File_Chooser.H>
#include <FL/fl_ask.H>
#include <FL/Fl_Window.H>
#include <FL/Fl_Shared_Image.H>
#include <FL/Fl_BMP_Image.H>
#include <FL/Fl_GIF_Image.H>
#include <FL/Fl_JPEG_Image.H>
#include <FL/Fl_PNG_Image.H>
#include <FL/Fl_XBM_Image.H>
#include <FL/Fl_XPM_Image.H>
#include <FL/Fl_Box.H>

int main(int argc, char** argv) {
	int h, w; 
	int len = 0;
	Fl_Image * fi_p = NULL;
	char title[128] = "";
	char filename[256];
	char ext[8];
	char *fn_p;
    fl_register_images();                       // initialize image lib
    memset(filename, 0, 256);
	if (argc > 1) {
		strncpy(filename, argv[1], 255);
	}
	else {
		fn_p = fl_file_chooser("Select Image File", 
					"JPEG Files (*.jpg)\tPNG Files (*.png)\tGIF Files (*.gif)\tBMP Files (*.bmp)"
					"\tXBM FIles (*.xbm)\tXPM Files (*.xpm)\tAll Files (*)", NULL, 0);
		if (fn_p) {
			strncpy(filename, fn_p, 255);
		}
	}
	len = strlen(filename);
	if (len > 4) {
		printf("Loading image '%s'\n", filename);
		if (len > 99) {
			fn_p = filename + len - 1;
			while (*fn_p != '/'&& fn_p > filename) {
				fn_p--;
			}
			if (*fn_p == '/') { 
				fn_p++;
			}
			strncpy(title, fn_p, 99);
		}
		else { 
			strncpy(title, filename, 99);
		}
		title[99] = '\0';
		strcat(title, " - FLTK Picture-See ");
		strcat(title, appver);
		printf("Title: '%s'\n", title);

		ext[0] = toupper(filename[len - 4]);
		ext[1] = toupper(filename[len - 3]);
		ext[2] = toupper(filename[len - 2]);
		ext[3] = toupper(filename[len - 1]);
		ext[4] = 0;
		
		printf("File type appears to be '%s'\n", ext);
		
		if (!strcmp(ext, ".JPG") || !strcmp(ext, "JPEG")) {
			fi_p = new Fl_JPEG_Image(filename); 
		}
		else if (!strcmp(ext, ".PNG")) {
			fi_p = new Fl_PNG_Image(filename);
		}
		else if (!strcmp(ext, ".BMP")) {
			fi_p = new Fl_BMP_Image(filename); 
		}
		else if (!strcmp(ext, ".GIF")) {
			fi_p = new Fl_GIF_Image(filename); 
		}
		else if (!strcmp(ext, ".XBM")) {
			fi_p = new Fl_XBM_Image(filename); 
		}
		else if (!strcmp(ext, ".XPM")) {
			fi_p = new Fl_XPM_Image(filename); 
		}
		else {
			fl_alert("File '%s' is not a known type.  FLTK Picture-See will exit.\n", filename);
			return -1;
		}
		
		h = fi_p->h(); 
		if (h < 80) h = 80;
		w = fi_p->w(); 
		if (w < 120) w = 120;
		
		Fl_Window     win(w + 24, h + 24, title);  
		Fl_Box        box(10,10, w + 2, h + 2);
		box.image(fi_p);                            
		win.show();
		return(Fl::run());
	}
} 
